· 8 years ago · Nov 18, 2017, 04:12 AM
117.11 23:04:33 [Server] INFO The chat was cleared by CONSOLE!
217.11 23:04:27 [Server] INFO Players: TRAINEE jbhjbh10, TRAINEE JBigBoyzEj
317.11 23:04:24 [Server] INFO Skipping modified: Plot;2;-1
417.11 23:04:24 [Server] INFO Skipping modified: Plot;2;1
517.11 23:04:19 [Server] INFO TheKrypton Ban » 124.187.148.72 was successfully banned!
617.11 23:04:10 [Server] INFO - Location: (world, -72, 36, -107)
717.11 23:04:10 [Server] INFO - IP Address: 124.187.148.72
817.11 23:04:10 [Server] INFO Player FreeZe_YT is offline since 2 minutes 17 seconds.
917.11 23:03:28 [Server] INFO Could not de-op FreeZe_YT
1017.11 23:03:28 [Server] INFO TheKrypton Ban » freeze_yt was successfully banned!
1117.11 23:03:26 [Server] INFO Players: TRAINEE jbhjbh10, TRAINEE JBigBoyzEj
1217.11 23:03:21 [Server] INFO Could not de-op FreeZe_YT
1317.11 23:03:18 [Server] INFO TheKrypton Ban » freeze_yt was successfully unbanned!
1417.11 23:02:48 [Server] INFO Unknown command. Type "/help" for help.
1517.11 23:02:39 [Server] INFO TheKrypton Ban » freeze_yt was successfully banned!
1617.11 23:02:34 [Server] INFO De-opped FreeZe_YT
1717.11 23:02:27 [Server] INFO TheKrypton Ban » freeze_yt was successfully unbanned!
1817.11 23:02:26 [Server] INFO Players: TRAINEE jbhjbh10, TRAINEE JBigBoyzEj
1917.11 23:02:24 [Server] INFO TheKrypton Ban » freeze_yt has already been banned!
2017.11 23:02:24 [Server] INFO Skipping modified: Plot;1;3
2117.11 23:02:24 [Server] INFO Skipping modified: Plot;2;0
2217.11 23:02:24 [Server] INFO Skipping modified: Plot;0;2
2317.11 23:02:24 [Server] INFO Skipping modified: Plot;-1;-2
2417.11 23:02:21 [Server] INFO Opped FreeZe_YT
2517.11 23:02:03 [Server] INFO [I] TRAINEE JBigBoyzEj [Staff] » Wait I want to see how this works out
2617.11 23:02:02 [Server] INFO i[iG-MPi]i [Z] TRAINEE jbhjbh10 [Ghoul] » cya
2717.11 23:01:55 [Server] INFO [I] TRAINEE JBigBoyzEj [Staff] » Alright. Gtg guys. Hope this gets resolved :/.
2817.11 23:01:55 [Server] WARN handleDisconnection() called twice
2917.11 23:01:55 [Server] INFO FreeZe_YT
3017.11 23:01:55 [Server] INFO §8» §awww.thekrypton.net
3117.11 23:01:55 [Server] INFO §8Apply for an unban on our website
3217.11 23:01:55 [Server] INFO §7
3317.11 23:01:55 [Server] INFO §aReason §8» §7none
3417.11 23:01:55 [Server] INFO §7
3517.11 23:01:55 [Server] INFO §7
3617.11 23:01:55 [Server] INFO §7You have been banned from TheKrypton Prison!
3717.11 23:01:55 [Disconnect] User FreeZe_YT has disconnected, reason: §2§lTheKrypton Ban §8§l»
3817.11 23:01:55 [Server] INFO TheKrypton Ban » freeze_yt was successfully banned!
3917.11 23:01:47 [Server] INFO De-opped FreeZe_YT
4017.11 23:01:34 [Server] INFO [I] TRAINEE JBigBoyzEj [Staff] » xD
4117.11 23:01:29 [Server] INFO TECHNICIAN FreeZe_YT » Lol
4217.11 23:01:25 [Server] INFO Players: TECHNICIAN FreeZe_YT, TRAINEE jbhjbh10, TRAINEE JBigBoyzEj
4317.11 23:01:10 [Server] INFO [I] TRAINEE JBigBoyzEj [Staff] » *But I wish I could*
4417.11 23:01:02 [Server] INFO TECHNICIAN FreeZe_YT » Alright
4517.11 23:01:00 [Server] INFO [I] TRAINEE JBigBoyzEj [Staff] » No.
4617.11 23:00:57 [Server] INFO [I] TRAINEE JBigBoyzEj [Staff] » What?
4717.11 23:00:56 [Server] INFO TECHNICIAN FreeZe_YT » Was it you that banned me?
4817.11 23:00:52 [Server] INFO TECHNICIAN FreeZe_YT » BigBoy
4917.11 23:00:47 [Server] INFO Region data changes made in 'KCells' have been background saved
5017.11 23:00:47 [Server] INFO Region data changes made in 'Plots' have been background saved
5117.11 23:00:47 [Server] INFO Region data changes made in 'MobArena' have been background saved
5217.11 23:00:47 [Server] INFO Region data changes made in 'DonatorMines' have been background saved
5317.11 23:00:47 [Server] INFO Region data changes made in 'Plot' have been background saved
5417.11 23:00:47 [Server] INFO Region data changes made in 'world_nether' have been background saved
5517.11 23:00:47 [Server] INFO Region data changes made in 'world_the_end' have been background saved
5617.11 23:00:47 [Server] INFO Region data changes made in 'world' have been background saved
5717.11 23:00:47 [Server] INFO Region data changes made in 'Yard' have been background saved
5817.11 23:00:39 [Server] INFO TheKrypton Ban » You are not able to ban freeze_yt
5917.11 23:00:28 [Server] INFO BigBoyzE
6017.11 23:00:28 [Server] INFO Player: BigBoyzE has 1 votes
6117.11 23:00:28 [Multicraft] BigBoyzE ran command Message of the Day
6217.11 23:00:28 [Connect] User BigBoyzE, IP 67.61.194.208
6317.11 23:00:28 [Server] INFO BigBoyzE's Cook Level is: 100
6417.11 23:00:27 [Server] INFO UUID of player BigBoyzE is ae539ce2-69a5-4159-b79a-87200b05efbd
6517.11 23:00:25 [Server] WARN ... 15 more
6617.11 23:00:25 [Server] WARN at java.lang.ClassLoader.loadClass(Unknown Source)
6717.11 23:00:25 [Server] WARN at java.lang.ClassLoader.loadClass(Unknown Source)
6817.11 23:00:25 [Server] WARN at org.bukkit.plugin.java.PluginClassLoader.findClass(PluginClassLoader.java:87)
6917.11 23:00:25 [Server] WARN at org.bukkit.plugin.java.PluginClassLoader.findClass(PluginClassLoader.java:92)
7017.11 23:00:25 [Server] WARN Caused by: java.lang.ClassNotFoundException: net.minecraft.server.v1_5_R3.Packet
7117.11 23:00:25 [Server] WARN at java.lang.Thread.run(Unknown Source)
7217.11 23:00:25 [Server] WARN at net.minecraft.server.v1_8_R3.MinecraftServer.run(MinecraftServer.java:616)
7317.11 23:00:25 [Server] WARN at net.minecraft.server.v1_8_R3.MinecraftServer.A(MinecraftServer.java:713)
7417.11 23:00:25 [Server] WARN at net.minecraft.server.v1_8_R3.DedicatedServer.B(DedicatedServer.java:378)
7517.11 23:00:25 [Server] WARN at net.minecraft.server.v1_8_R3.MinecraftServer.B(MinecraftServer.java:783)
7617.11 23:00:25 [Server] WARN at org.bukkit.craftbukkit.v1_8_R3.scheduler.CraftScheduler.mainThreadHeartbeat(CraftScheduler.java:352)
7717.11 23:00:25 [Server] WARN at org.bukkit.craftbukkit.v1_8_R3.scheduler.CraftTask.run(CraftTask.java:59)
7817.11 23:00:25 [Server] WARN at net.citizensnpcs.npc.profile.ProfileRequest$1.run(ProfileRequest.java:118)
7917.11 23:00:25 [Server] WARN at net.citizensnpcs.npc.skin.Skin$1.onResult(Skin.java:222)
8017.11 23:00:25 [Server] WARN at net.citizensnpcs.npc.skin.Skin.access$600(Skin.java:32)
8117.11 23:00:25 [Server] WARN at net.citizensnpcs.npc.skin.Skin.setData(Skin.java:179)
8217.11 23:00:25 [Server] WARN at net.citizensnpcs.npc.skin.Skin.applyAndRespawn(Skin.java:128)
8317.11 23:00:25 [Server] WARN at net.citizensnpcs.npc.CitizensNPC.spawn(CitizensNPC.java:235)
8417.11 23:00:25 [Server] WARN at net.aufdemrand.sentry.SentryTrait.onSpawn(SentryTrait.java:113)
8517.11 23:00:25 [Server] WARN at net.aufdemrand.sentry.SentryTrait.ensureInst(SentryTrait.java:134)
8617.11 23:00:25 [Server] WARN java.lang.NoClassDefFoundError: net/minecraft/server/v1_5_R3/Packet
8717.11 23:00:25 [Server] ERROR An exception occurred while the trait sentry was spawning for NPC ID 53.
8817.11 23:00:25 [Server] INFO Skipping modified: Plot;0;0
8917.11 23:00:25 [Server] INFO Skipping modified: Plot;-1;-1
9017.11 23:00:25 [Server] INFO Skipping modified: Plot;1;1
9117.11 23:00:25 [Server] INFO Cached a total of: 33 UUIDs
9217.11 23:00:25 [Server] INFO Fast mode UUID caching enabled!
9317.11 23:00:25 [Server] INFO Starting player data caching for: world
9417.11 23:00:25 [Server] INFO Starting UUID caching
9517.11 23:00:25 [Server] WARN Please restart your Server in order to use the new Version
9617.11 23:00:25 [Server] WARN CS-CoreLib was successfully updated (1.5.7 -> 1.5.15)
9717.11 23:00:25 [Server] WARN #################### - UPDATE - ####################
9817.11 23:00:25 [Server] WARN at java.lang.Thread.run(Unknown Source)
9917.11 23:00:25 [Server] WARN at net.minecraft.server.v1_8_R3.MinecraftServer.run(MinecraftServer.java:616)
10017.11 23:00:25 [Server] WARN at net.minecraft.server.v1_8_R3.MinecraftServer.A(MinecraftServer.java:713)
10117.11 23:00:25 [Server] WARN at net.minecraft.server.v1_8_R3.DedicatedServer.B(DedicatedServer.java:378)
10217.11 23:00:25 [Server] WARN at net.minecraft.server.v1_8_R3.MinecraftServer.B(MinecraftServer.java:783)
10317.11 23:00:25 [Server] WARN at org.bukkit.craftbukkit.v1_8_R3.scheduler.CraftScheduler.mainThreadHeartbeat(CraftScheduler.java:352)
10417.11 23:00:25 [Server] WARN at org.bukkit.craftbukkit.v1_8_R3.scheduler.CraftTask.run(CraftTask.java:59)
10517.11 23:00:25 [Server] WARN at me.mrCookieSlime.CSCoreLibPlugin.updater.Updater$UpdaterTask$1.run(Updater.java:137)
10617.11 23:00:25 [Server] WARN at java.net.URL.openStream(Unknown Source)
10717.11 23:00:25 [Server] WARN at sun.net.www.protocol.http.HttpURLConnection.getInputStream(Unknown Source)
10817.11 23:00:25 [Server] WARN at sun.net.www.protocol.http.HttpURLConnection.getInputStream0(Unknown Source)
10917.11 23:00:25 [Server] WARN java.io.IOException: Server returned HTTP response code: 400 for URL: http://servermods.cursecdn.com/files/2433/952/CS-CoreLib v1.5.15.jar
11017.11 23:00:25 [Server] WARN #################### - ERROR - ####################
11117.11 23:00:25 [Server] WARN Could not auto-update CS-CoreLib
11217.11 23:00:25 [Server] WARN #################### - ERROR - ####################
11317.11 23:00:24 [Server] INFO jbhjbh10
11417.11 23:00:24 [Server] INFO FreeZe_YT
11517.11 23:00:24 [Server] INFO TheKrypton Ban » You are not able to ban freeze_yt
11617.11 23:00:24 [Server] INFO Player: FreeZe_YT has 26 votes
11717.11 23:00:24 [Server] INFO Player: jbhjbh10 has 112 votes
11817.11 23:00:24 [Multicraft] jbhjbh10 ran command Message of the Day
11917.11 23:00:24 [Connect] User jbhjbh10, IP 75.169.14.147
12017.11 23:00:24 [Server] INFO jbhjbh10's Cook Level is: 100
12117.11 23:00:24 [Multicraft] FreeZe_YT ran command Message of the Day
12217.11 23:00:24 [Connect] User FreeZe_YT, IP 124.187.148.72
12317.11 23:00:24 [Server] INFO FreeZe_YT's Cook Level is: 100
12417.11 23:00:23 [Server] INFO No new version available
12517.11 23:00:23 [Server] INFO You are running the latest version of PlotSquared
12617.11 23:00:23 [Server] INFO Checking for Updates ...
12717.11 23:00:23 [Server] INFO at java.lang.Thread.run(Unknown Source) [?:1.8.0_77]
12817.11 23:00:23 [Server] INFO at net.minecraft.server.v1_8_R3.MinecraftServer.run(MinecraftServer.java:616) [patched.jar:git-PaperSpigot-443]
12917.11 23:00:23 [Server] INFO at net.minecraft.server.v1_8_R3.MinecraftServer.A(MinecraftServer.java:713) [patched.jar:git-PaperSpigot-443]
13017.11 23:00:23 [Server] INFO at net.minecraft.server.v1_8_R3.DedicatedServer.B(DedicatedServer.java:378) [patched.jar:git-PaperSpigot-443]
13117.11 23:00:23 [Server] INFO at net.minecraft.server.v1_8_R3.MinecraftServer.B(MinecraftServer.java:783) [patched.jar:git-PaperSpigot-443]
13217.11 23:00:23 [Server] INFO at org.bukkit.craftbukkit.v1_8_R3.scheduler.CraftScheduler.mainThreadHeartbeat(CraftScheduler.java:352) [patched.jar:git-PaperSpigot-443]
13317.11 23:00:23 [Server] INFO at org.bukkit.craftbukkit.v1_8_R3.scheduler.CraftTask.run(CraftTask.java:59) ~[patched.jar:git-PaperSpigot-443]
13417.11 23:00:23 [Server] INFO at net.citizensnpcs.Citizens$2.run(Citizens.java:299) ~[?:?]
13517.11 23:00:23 [Server] INFO at net.citizensnpcs.Citizens.access$300(Citizens.java:66) ~[?:?]
13617.11 23:00:23 [Server] INFO at net.citizensnpcs.Citizens.startMetrics(Citizens.java:426) ~[?:?]
13717.11 23:00:23 [Server] INFO at net.citizensnpcs.npc.CitizensTraitFactory.addPlotters(CitizensTraitFactory.java:99) ~[?:?]
13817.11 23:00:23 [Server] INFO at net.citizensnpcs.Metrics$Graph.addPlotter(Metrics.java:530) ~[?:?]
13917.11 23:00:23 [Server] INFO at java.util.HashSet.add(Unknown Source) ~[?:1.8.0_77]
14017.11 23:00:23 [Server] INFO at java.util.HashMap.put(Unknown Source) ~[?:1.8.0_77]
14117.11 23:00:23 [Server] INFO at java.util.HashMap.hash(Unknown Source) ~[?:1.8.0_77]
14217.11 23:00:23 [Server] INFO at net.citizensnpcs.Metrics$Plotter.hashCode(Metrics.java:640) ~[?:?]
14317.11 23:00:23 [Server] INFO java.lang.NullPointerException
14417.11 23:00:23 [Server] WARN Task #465 for Citizens v2.0.16-SNAPSHOT (build 1267) generated an exception
14517.11 23:00:23 [Server] INFO Loaded 5 NPCs.
14617.11 23:00:23 [Server] WARN ... 13 more
14717.11 23:00:23 [Server] WARN at java.lang.ClassLoader.loadClass(Unknown Source)
14817.11 23:00:23 [Server] WARN at java.lang.ClassLoader.loadClass(Unknown Source)
14917.11 23:00:23 [Server] WARN at org.bukkit.plugin.java.PluginClassLoader.findClass(PluginClassLoader.java:87)
15017.11 23:00:23 [Server] WARN at org.bukkit.plugin.java.PluginClassLoader.findClass(PluginClassLoader.java:92)
15117.11 23:00:23 [Server] WARN Caused by: java.lang.ClassNotFoundException: net.minecraft.server.v1_5_R3.Packet
15217.11 23:00:23 [Server] WARN at java.lang.Thread.run(Unknown Source)
15317.11 23:00:23 [Server] WARN at net.minecraft.server.v1_8_R3.MinecraftServer.run(MinecraftServer.java:616)
15417.11 23:00:23 [Server] WARN at net.minecraft.server.v1_8_R3.MinecraftServer.A(MinecraftServer.java:713)
15517.11 23:00:23 [Server] WARN at net.minecraft.server.v1_8_R3.DedicatedServer.B(DedicatedServer.java:378)
15617.11 23:00:23 [Server] WARN at net.minecraft.server.v1_8_R3.MinecraftServer.B(MinecraftServer.java:783)
15717.11 23:00:23 [Server] WARN at org.bukkit.craftbukkit.v1_8_R3.scheduler.CraftScheduler.mainThreadHeartbeat(CraftScheduler.java:352)
15817.11 23:00:23 [Server] WARN at org.bukkit.craftbukkit.v1_8_R3.scheduler.CraftTask.run(CraftTask.java:59)
15917.11 23:00:23 [Server] WARN at net.citizensnpcs.Citizens$2.run(Citizens.java:297)
16017.11 23:00:23 [Server] WARN at net.citizensnpcs.api.npc.SimpleNPCDataStore.loadInto(SimpleNPCDataStore.java:59)
16117.11 23:00:23 [Server] WARN at net.citizensnpcs.npc.CitizensNPC.load(CitizensNPC.java:132)
16217.11 23:00:23 [Server] WARN at net.citizensnpcs.npc.CitizensNPC.spawn(CitizensNPC.java:235)
16317.11 23:00:23 [Server] WARN at net.aufdemrand.sentry.SentryTrait.onSpawn(SentryTrait.java:113)
16417.11 23:00:23 [Server] WARN at net.aufdemrand.sentry.SentryTrait.ensureInst(SentryTrait.java:134)
16517.11 23:00:23 [Server] WARN java.lang.NoClassDefFoundError: net/minecraft/server/v1_5_R3/Packet
16617.11 23:00:23 [Server] ERROR An exception occurred while the trait sentry was spawning for NPC ID 53.
16717.11 23:00:23 [Server] INFO The trait sentry failed to load for NPC ID: 53.
16817.11 23:00:23 [Server] INFO Downloading CS-CoreLib v1.5.15
16917.11 23:00:23 [Server] INFO CS-CoreLib is outdated!
17017.11 23:00:23 [Server] INFO QuickSell is up to date!
17117.11 23:00:23 [Server] INFO Loaded 22 queued votes
17217.11 23:00:23 [Server] INFO Loading queued votes
17317.11 23:00:23 [Server] INFO Enabling PaperSpigot/TacoSpigot patch: Fixes block placement.
17417.11 23:00:23 [Server] INFO No update was found.
17517.11 23:00:23 [Server] INFO ViaVersion detected server version: 1.8.x(47)
17617.11 23:00:23 [Server] INFO Connection established!
17717.11 23:00:23 [Server] INFO We didn't find an update!
17817.11 23:00:23 [Server] INFO ** Vaults have already been converted to UUIDs. If this is incorrect, shutdown your server and rename the plugins/PlayerVaults/uuidvaults directory.
17917.11 23:00:23 [Server] INFO Found economy provider Vault
18017.11 23:00:23 [Server] INFO dev.bukkit.org/bukkit-plugins/holographic-displays
18117.11 23:00:23 [Server] INFO Download it on Bukkit Dev:
18217.11 23:00:23 [Server] INFO Found a new version available: v2.2.6
18317.11 23:00:23 [Server] INFO Timings Reset
18417.11 23:00:23 [Server] Startup Done (15.327s)! For help, type "help" or "?"
18517.11 23:00:23 [Server] INFO Server permissions file permissions.yml is empty, ignoring it
18617.11 23:00:23 [Server] INFO *** Hooked into AutoSell! ***
18717.11 23:00:23 [Server] INFO Enabling InventoryFull v1.7.1
18817.11 23:00:23 [Server] INFO Vault linked! Group targets will work.
18917.11 23:00:23 [Server] INFO Sentinel loaded!
19017.11 23:00:23 [Server] INFO Sentinel loading...
19117.11 23:00:23 [Server] INFO Enabling Sentinel v1.4.5 (build 155)
19217.11 23:00:23 [Server] WARN @Deprecation: ROULETTEKEYCRATE. https://github.com/imWillX/CrateReloaded/issues/152
19317.11 23:00:23 [Server] WARN @Deprecation: ROULETTEKEYCRATE. https://github.com/imWillX/CrateReloaded/issues/152
19417.11 23:00:23 [Server] WARN @Deprecation: ROULETTEKEYCRATE. https://github.com/imWillX/CrateReloaded/issues/152
19517.11 23:00:23 [Server] WARN @Deprecation: ROULETTEKEYCRATE. https://github.com/imWillX/CrateReloaded/issues/152
19617.11 23:00:23 [Server] INFO v1_8_R3
19717.11 23:00:23 [Server] INFO Enabling CrateReloaded v1.3.98.2
19817.11 23:00:23 [Server] INFO ---------------------------
19917.11 23:00:23 [Server] INFO Download at http://www.spigotmc.org/resources/autosell.2157/
20017.11 23:00:23 [Server] INFO You are running 1.6.4
20117.11 23:00:23 [Server] INFO AutoSell 1.8.1
20217.11 23:00:23 [Server] INFO An update for AutoSell has been found!
20317.11 23:00:23 [Server] INFO AutoSell Updater
20417.11 23:00:23 [Server] INFO ---------------------------
20517.11 23:00:22 [Server] INFO 0 shop signs have been loaded!
20617.11 23:00:22 [Server] INFO 1 permission based shop multipliers have been loaded!
20717.11 23:00:22 [Server] INFO 1 permission based multipliers loaded!
20817.11 23:00:22 [Server] INFO 0 saved multipliers have been loaded!
20917.11 23:00:22 [Server] INFO BlockBreakEvent priority set to HIGHEST!
21017.11 23:00:22 [Server] INFO MineResetLite was detected and shops will be set per mine!
21117.11 23:00:22 [Server] INFO 4 auto smelt entries loaded!
21217.11 23:00:22 [Server] INFO 1 shops loaded!
21317.11 23:00:22 [Server] INFO Loading AutoSell messages.yml
21417.11 23:00:22 [Server] INFO Enabling AutoSell v1.6.4
21517.11 23:00:22 [Server] INFO The Delivery Man Enabled The Delivery Man v2.2.2
21617.11 23:00:22 [Server] INFO The Delivery Man You have setted AutoUpdater on false! You will not receive any updates from this plugin!
21717.11 23:00:22 [Server] INFO The Delivery Man Loading The Delivery Man... v2.2.2
21817.11 23:00:22 [Server] INFO Enabling DeliveryMan v2.2.2
21917.11 23:00:22 [Server] WARN Could not recognize Item String: "END_STONE"
22017.11 23:00:22 [Server] WARN Could not recognize Item String: "DARK_PRISMARINE"
22117.11 23:00:22 [Server] WARN Could not recognize Item String: "END_STONE"
22217.11 23:00:22 [Server] WARN Could not recognize Item String: "DARK_PRISMARINE"
22317.11 23:00:22 [Server] WARN Could not recognize Item String: "END_STONE"
22417.11 23:00:22 [Server] WARN Could not recognize Item String: "DARK_PRISMARINE"
22517.11 23:00:22 [Server] WARN Could not recognize Item String: "GLOWTONE"
22617.11 23:00:22 [Server] WARN Could not recognize Item String: "RED_STAINED_CLAY"
22717.11 23:00:22 [Server] WARN Could not recognize Item String: "INK_SAC"
22817.11 23:00:22 [Server] WARN Could not recognize Item String: "NETHER_QUARTZ"
22917.11 23:00:22 [Server] WARN Could not recognize Item String: "NETHER_QUARTZ"
23017.11 23:00:22 [Server] WARN Could not recognize Item String: "INK_SAC"
23117.11 23:00:22 [Server] INFO Enabling QuickSell v2.0.6
23217.11 23:00:22 [Server] INFO Enabling featherboard support
23317.11 23:00:22 [Server] INFO Registered custom placeholder: {safelogout}
23417.11 23:00:22 [Server] INFO Registered custom placeholder: {combattime}
23517.11 23:00:22 [Server] INFO Enabling CombatTag v7.0.0-beta-1-SNAPSHOT
23617.11 23:00:22 [Server] INFO 31 prestiges loaded!
23717.11 23:00:22 [Server] INFO Enabling EZPrestige v1.2.2
23817.11 23:00:22 [Server] INFO Loaded 1 cells(s)
23917.11 23:00:22 [Server] INFO Max rental length set to '28days'
24017.11 23:00:22 [Server] INFO Rental period set to '24hours'
24117.11 23:00:21 [Server] INFO Enabling PrisonCells v2.3
24217.11 23:00:21 [Server] INFO Could not find or register with SimpleClans.
24317.11 23:00:21 [Server] INFO Could not find or register with War.
24417.11 23:00:21 [Server] INFO Could not find or register with Factions.
24517.11 23:00:21 [Server] INFO Could not find or register with Towny
24617.11 23:00:21 [Server] INFO Could not register with Denizen
24717.11 23:00:21 [Server] INFO Enabling Sentry v1.3.6
24817.11 23:00:21 [Server] WARN Hologram 'd-a-c2' was in the world 'Cells' but it wasn't loaded.
24917.11 23:00:21 [Server] WARN Hologram 'd-a-c1' was in the world 'Cells' but it wasn't loaded.
25017.11 23:00:21 [Server] WARN Hologram 'kbs' was in the world 'Cells' but it wasn't loaded.
25117.11 23:00:21 [Server] WARN Hologram 'dct3' was in the world 'Cells' but it wasn't loaded.
25217.11 23:00:21 [Server] WARN Hologram 'dct2' was in the world 'Cells' but it wasn't loaded.
25317.11 23:00:21 [Server] WARN Hologram 'dct1' was in the world 'Cells' but it wasn't loaded.
25417.11 23:00:21 [Server] WARN Hologram 'kci2' was in the world 'Cells' but it wasn't loaded.
25517.11 23:00:21 [Server] WARN Hologram 'kmi' was in the world 'Cells' but it wasn't loaded.
25617.11 23:00:21 [Server] WARN Hologram 'ct4' was in the world 'Cells' but it wasn't loaded.
25717.11 23:00:21 [Server] WARN Hologram 'ct3' was in the world 'Cells' but it wasn't loaded.
25817.11 23:00:21 [Server] WARN Hologram 'kc1' was in the world 'Cells' but it wasn't loaded.
25917.11 23:00:21 [Server] WARN Hologram 'ct2' was in the world 'Cells' but it wasn't loaded.
26017.11 23:00:21 [Server] WARN Hologram 'ct1' was in the world 'Cells' but it wasn't loaded.
26117.11 23:00:21 [Server] WARN Hologram 'fun' was in the world 'ManInWhite' but it wasn't loaded.
26217.11 23:00:21 [Server] WARN Hologram 'k3' was in the world 'ManInWhite' but it wasn't loaded.
26317.11 23:00:21 [Server] WARN Hologram 'k' was in the world 'ManInWhite' but it wasn't loaded.
26417.11 23:00:21 [Server] WARN Hologram 'k2' was in the world 'ManInWhite' but it wasn't loaded.
26517.11 23:00:21 [Server] WARN Hologram 'pk2' was in the world 'ManInWhite' but it wasn't loaded.
26617.11 23:00:21 [Server] WARN Hologram 'pk1' was in the world 'ManInWhite' but it wasn't loaded.
26717.11 23:00:21 [Server] INFO Found ProtocolLib, adding support for player relative variables.
26817.11 23:00:21 [Server] INFO Enabling HolographicDisplays v2.1.12
26917.11 23:00:21 [Server] INFO v0.98.1 enabled.
27017.11 23:00:21 [Server] INFO Loaded arena 'forest'
27117.11 23:00:21 [Server] INFO Loaded arena 'Sandstone'
27217.11 23:00:21 [Server] INFO Loaded arena 'Temple'
27317.11 23:00:21 [Server] INFO Loaded arena 'Forest'
27417.11 23:00:21 [Server] INFO Loaded arena 'default'
27517.11 23:00:21 [Server] INFO Vault found; economy rewards enabled.
27617.11 23:00:21 [Server] INFO Enabling MobArena v0.98.1
27717.11 23:00:21 [Server] INFO Vault loaded! Found an economy plugin!
27817.11 23:00:21 [Server] INFO executed create table statement changed 0 rows: CREATE INDEX IF NOT EXISTS `accounts_shortName_idx` ON `accounts` ( `shortName` )
27917.11 23:00:21 [Server] INFO executed create table statement changed 0 rows: CREATE TABLE IF NOT EXISTS `accounts` (`lastSeenName` VARCHAR NOT NULL , `name` VARCHAR NOT NULL , `shortName` VARCHAR NOT NULL , `uuid` VARCHAR NOT NULL , PRIMARY KEY (`name`) )
28017.11 23:00:21 [Server] INFO creating index 'accounts_shortName_idx' for table 'accounts
28117.11 23:00:21 [Server] INFO creating table 'accounts'
28217.11 23:00:21 [Server] ERROR WARNING: you seem to not be using the Xerial SQLite driver. See ORMLite docs on SQLite: http://ormlite.com/docs/sqlite
28317.11 23:00:21 [Server] INFO executed create table statement changed 0 rows: CREATE TABLE IF NOT EXISTS `items` (`id` INTEGER PRIMARY KEY AUTOINCREMENT , `code` VARCHAR NOT NULL , UNIQUE (`code`))
28417.11 23:00:21 [Server] INFO creating table 'items'
28517.11 23:00:21 [Server] ERROR WARNING: you seem to not be using the Xerial SQLite driver. See ORMLite docs on SQLite: http://ormlite.com/docs/sqlite
28617.11 23:00:21 [Server] INFO Enabling ChestShop v3.8.12
28717.11 23:00:21 [Server] INFO Version 1.8 detected. Legacy Edition intialising...
28817.11 23:00:21 [Server] INFO ###########################################
28917.11 23:00:21 [Server] INFO # Current Server Version: git-PaperSpigot-443 (MC: 1.8.8)
29017.11 23:00:21 [Server] INFO # Current Cartel Version: 1.5.2
29117.11 23:00:21 [Server] INFO # Cartel Player Data Loading...
29217.11 23:00:21 [Server] INFO # playerData.yml found, loaded.
29317.11 23:00:21 [Server] INFO #
29417.11 23:00:21 [Server] INFO # Cartel Data Cache Successfully Loaded!
29517.11 23:00:21 [Server] INFO # dataCache.yml found, loading...
29617.11 23:00:21 [Server] INFO #
29717.11 23:00:21 [Server] INFO # Cartel Drug Locations Loading...
29817.11 23:00:21 [Server] INFO # drugLocations.yml found, loaded.
29917.11 23:00:21 [Server] INFO #
30017.11 23:00:21 [Server] INFO # Cartel config data Loading...
30117.11 23:00:21 [Server] INFO # config.yml found, loaded.
30217.11 23:00:21 [Server] INFO #
30317.11 23:00:21 [Server] INFO # LeaderHeads not found/enabled! Ignoring...
30417.11 23:00:21 [Server] INFO #
30517.11 23:00:21 [Server] INFO # Vault found! Economy enabling...
30617.11 23:00:21 [Server] INFO # Citizens found! Dealers enabling...
30717.11 23:00:21 [Server] INFO # Loading all dependencies:
30817.11 23:00:21 [Server] INFO ###################Cartel##################
30917.11 23:00:21 [Server] INFO Enabling Cartel v1.5.2
31017.11 23:00:21 [Server] INFO (Current flags: invincible: ALLOW, pvp: ALLOW, block-break: ALLOW, build: DENY, fall-damage: DENY)
31117.11 23:00:21 [Server] INFO Region flag block-break set on '__global__' to 'allow'.
31217.11 23:00:21 [Server] INFO (Current flags: invincible: ALLOW, pvp: ALLOW, block-break: ALLOW, build: DENY, fall-damage: DENY)
31317.11 23:00:21 [Server] INFO Region flag pvp set on '__global__' to 'allow'.
31417.11 23:00:21 [Server] INFO (Current flags: other-explosion: DENY, pvp: ALLOW, mob-spawning: DENY, creeper-explosion: DENY, fire-spread: DENY, block-break: ALLOW, build: DENY)
31517.11 23:00:21 [Server] INFO Region flag block-break set on '__global__' to 'allow'.
31617.11 23:00:21 [Server] INFO (Current flags: other-explosion: DENY, pvp: ALLOW, mob-spawning: DENY, creeper-explosion: DENY, fire-spread: DENY, block-break: ALLOW, build: DENY)
31717.11 23:00:21 [Server] INFO Region flag pvp set on '__global__' to 'allow'.
31817.11 23:00:21 [Server] INFO (Current flags: invincible: ALLOW, pvp: ALLOW, block-break: ALLOW, fall-damage: DENY)
31917.11 23:00:21 [Server] INFO Region flag block-break set on '__global__' to 'allow'.
32017.11 23:00:21 [Server] INFO (Current flags: invincible: ALLOW, pvp: ALLOW, block-break: ALLOW, fall-damage: DENY)
32117.11 23:00:21 [Server] INFO Region flag pvp set on '__global__' to 'allow'.
32217.11 23:00:21 [Server] INFO (Current flags: pvp: ALLOW, block-break: ALLOW, fall-damage: DENY)
32317.11 23:00:21 [Server] INFO Region flag block-break set on '__global__' to 'allow'.
32417.11 23:00:21 [Server] INFO (Current flags: pvp: ALLOW, block-break: ALLOW, fall-damage: DENY)
32517.11 23:00:21 [Server] INFO Region flag pvp set on '__global__' to 'allow'.
32617.11 23:00:21 [Server] INFO (Current flags: pvp: ALLOW, block-break: ALLOW, build: DENY, fall-damage: DENY)
32717.11 23:00:21 [Server] INFO Region flag block-break set on '__global__' to 'allow'.
32817.11 23:00:21 [Server] INFO (Current flags: pvp: ALLOW, block-break: ALLOW, build: DENY, fall-damage: DENY)
32917.11 23:00:21 [Server] INFO Region flag pvp set on '__global__' to 'allow'.
33017.11 23:00:21 [Server] INFO (Current flags: pvp: ALLOW, mob-spawning: DENY, block-break: ALLOW)
33117.11 23:00:21 [Server] INFO Region flag block-break set on '__global__' to 'allow'.
33217.11 23:00:21 [Server] INFO (Current flags: pvp: ALLOW, mob-spawning: DENY, block-break: ALLOW)
33317.11 23:00:21 [Server] INFO Region flag pvp set on '__global__' to 'allow'.
33417.11 23:00:21 [Server] INFO (Current flags: pvp: ALLOW, block-break: ALLOW)
33517.11 23:00:21 [Server] INFO Region flag block-break set on '__global__' to 'allow'.
33617.11 23:00:21 [Server] INFO (Current flags: pvp: ALLOW, block-break: ALLOW)
33717.11 23:00:21 [Server] INFO Region flag pvp set on '__global__' to 'allow'.
33817.11 23:00:21 [Server] INFO (Current flags: pvp: ALLOW, block-break: ALLOW)
33917.11 23:00:21 [Server] INFO Region flag block-break set on '__global__' to 'allow'.
34017.11 23:00:21 [Server] INFO (Current flags: pvp: ALLOW, block-break: ALLOW)
34117.11 23:00:21 [Server] INFO Region flag pvp set on '__global__' to 'allow'.
34217.11 23:00:21 [Server] INFO (Current flags: use: ALLOW, pvp: ALLOW, mob-spawning: ALLOW, damage-animals: ALLOW, time-lock: 12am, chest-access: ALLOW, block-break: ALLOW, build: DENY, fall-damage: DENY)
34317.11 23:00:21 [Server] INFO Region flag block-break set on '__global__' to 'allow'.
34417.11 23:00:21 [Server] INFO (Current flags: use: ALLOW, pvp: ALLOW, mob-spawning: ALLOW, damage-animals: ALLOW, time-lock: 12am, chest-access: ALLOW, build: DENY, fall-damage: DENY)
34517.11 23:00:21 [Server] INFO Region flag pvp set on '__global__' to 'allow'.
34617.11 23:00:20 [Server] INFO Enabling RandomPackage v13-hotfix4
34717.11 23:00:20 [Server] INFO Loading mine from file 'M-Mine.mine.yml'...
34817.11 23:00:20 [Server] INFO Loading mine from file 'Mobster.mine.yml'...
34917.11 23:00:20 [Server] INFO Loading mine from file 'T-Mine.mine.yml'...
35017.11 23:00:20 [Server] INFO Loading mine from file 'X.mine.yml'...
35117.11 23:00:20 [Server] INFO Loading mine from file 'gangster.mine.yml'...
35217.11 23:00:20 [Server] INFO Loading mine from file 'bigboy-emerald.mine.yml'...
35317.11 23:00:20 [Server] INFO Loading mine from file 'Thug-Mine.mine.yml'...
35417.11 23:00:20 [Server] INFO Loading mine from file 'C.mine.yml'...
35517.11 23:00:20 [Server] INFO Loading mine from file 'F-Mine.mine.yml'...
35617.11 23:00:20 [Server] INFO Loading mine from file 'jbh-pmine2.mine.yml'...
35717.11 23:00:20 [Server] INFO Loading mine from file 'B-Mine.mine.yml'...
35817.11 23:00:20 [Server] INFO Loading mine from file 'Sledge-1.mine.yml'...
35917.11 23:00:20 [Server] INFO Loading mine from file 'prestige1.mine.yml'...
36017.11 23:00:20 [Server] INFO Loading mine from file 'P-Mine.mine.yml'...
36117.11 23:00:20 [Server] INFO Loading mine from file 'Wood1.mine.yml'...
36217.11 23:00:20 [Server] INFO Loading mine from file 'H.mine.yml'...
36317.11 23:00:20 [Server] INFO Loading mine from file 'O-Mine.mine.yml'...
36417.11 23:00:20 [Server] INFO Loading mine from file 'I-Mine.mine.yml'...
36517.11 23:00:20 [Server] INFO Loading mine from file 'Z-Mine.mine.yml'...
36617.11 23:00:20 [Server] INFO Loading mine from file 'bigboy-gold.mine.yml'...
36717.11 23:00:20 [Server] INFO Loading mine from file 'J-Mine.mine.yml'...
36817.11 23:00:20 [Server] INFO Loading mine from file 'Capone.mine.yml'...
36917.11 23:00:20 [Server] INFO Loading mine from file 'jbh-pmine.mine.yml'...
37017.11 23:00:20 [Server] INFO Loading mine from file 'U-Mine.mine.yml'...
37117.11 23:00:20 [Server] INFO Loading mine from file 'Sledge-3.mine.yml'...
37217.11 23:00:20 [Server] INFO Loading mine from file 'E-Mine.mine.yml'...
37317.11 23:00:20 [Server] INFO Loading mine from file 'S.mine.yml'...
37417.11 23:00:20 [Server] INFO Loading mine from file 'Y.mine.yml'...
37517.11 23:00:20 [Server] INFO Loading mine from file 'Q-Mine.mine.yml'...
37617.11 23:00:20 [Server] INFO Loading mine from file 'A-Mine.mine.yml'...
37717.11 23:00:20 [Server] INFO Loading mine from file 'bigboy-iron.mine.yml'...
37817.11 23:00:20 [Server] INFO Loading mine from file 'R-Mine.mine.yml'...
37917.11 23:00:20 [Server] INFO Loading mine from file 'InmateMine.mine.yml'...
38017.11 23:00:20 [Server] INFO Loading mine from file 'Dealer.mine.yml'...
38117.11 23:00:20 [Server] INFO Loading mine from file 'Wood2.mine.yml'...
38217.11 23:00:20 [Server] INFO Loading mine from file 'Kingpin.mine.yml'...
38317.11 23:00:20 [Server] INFO Loading mine from file 'D-Mine.mine.yml'...
38417.11 23:00:20 [Server] INFO Loading mine from file 'L-Mine.mine.yml'...
38517.11 23:00:20 [Server] INFO Loading mine from file 'B-Mine2.mine.yml'...
38617.11 23:00:20 [Server] INFO Loading mine from file 'K-Mine.mine.yml'...
38717.11 23:00:20 [Server] INFO Loading mine from file 'G-Mine.mine.yml'...
38817.11 23:00:20 [Server] INFO Loading mine from file 'N-Mine.mine.yml'...
38917.11 23:00:20 [Server] INFO Loading mine from file 'Convictmine.mine.yml'...
39017.11 23:00:20 [Server] INFO Loading mine from file 'staffmine.mine.yml'...
39117.11 23:00:20 [Server] INFO Loading mine from file 'Sledge-2.mine.yml'...
39217.11 23:00:20 [Server] INFO Loading mine from file 'V-Mine.mine.yml'...
39317.11 23:00:20 [Server] INFO Loading mine from file 'W.mine.yml'...
39417.11 23:00:20 [Server] INFO For any issues or suggestions, use the Spigot discussion thread. Do not PM any of the developers.
39517.11 23:00:20 [Server] INFO MRL is managed and developed by Boomclaw under the Apache 2.0 license.
39617.11 23:00:20 [Server] INFO Enabling MineResetLite v0.4.7
39717.11 23:00:20 [Server] INFO Loaded Protection Module "WorldGuard"
39817.11 23:00:20 [Server] INFO Enabling CS-CoreLib v1.5.7
39917.11 23:00:20 [Server] INFO Enabling Citizens v2.0.16-SNAPSHOT (build 1267)
40017.11 23:00:20 [Server] INFO Version 2.5.0-b727 (API v20) Enabled - By Rigby, fernferret, lithium3141, main-- and dumptruckman
40117.11 23:00:20 [Server] INFO 9 - World(s) loaded.
40217.11 23:00:20 [Server] INFO Loaded configuration for world 'DonatorMines'
40317.11 23:00:20 [Server] INFO (DonatorMines) Fire spread is UNRESTRICTED.
40417.11 23:00:20 [Server] INFO (DonatorMines) Lava fire is blocked.
40517.11 23:00:20 [Server] INFO (DonatorMines) Lighters are PERMITTED.
40617.11 23:00:20 [Server] INFO (DonatorMines) TNT ignition is PERMITTED.
40717.11 23:00:20 [Server] INFO Preparing start region for level 8 (Seed: 3230313466938260640)
40817.11 23:00:20 [Server] INFO BukkitPlotGenerator does not fully support: null
40917.11 23:00:20 [Server] INFO World async lighting: false
41017.11 23:00:20 [Server] INFO Keep spawn chunk loaded: true
41117.11 23:00:20 [Server] INFO WorldServer TickNextTickList cap always processes redstone: false
41217.11 23:00:20 [Server] INFO WorldServer TickNextTick cap set at 10000
41317.11 23:00:20 [Server] INFO Allow undead horse types to be leashed: false
41417.11 23:00:20 [Server] INFO Fix TNT cannons: false
41517.11 23:00:20 [Server] INFO Water over lava flow speed: 5
41617.11 23:00:20 [Server] INFO Living Entity Despawn Ranges: Soft: 32 Hard: 128
41717.11 23:00:20 [Server] INFO Max height for cactus growth 3. Max height for reed growth 3
41817.11 23:00:20 [Server] INFO Squids will spawn between Y: 45.0 and Y: 63.0
41917.11 23:00:20 [Server] INFO Player blocking damage multiplier set to 0.5
42017.11 23:00:20 [Server] INFO Remove invalid mob spawner tile entities: true
42117.11 23:00:20 [Server] INFO -------- World Settings For [DonatorMines] --------
42217.11 23:00:20 [Server] INFO Experience Merge Radius: 3.0
42317.11 23:00:20 [Server] INFO Clear tick list: false
42417.11 23:00:20 [Server] INFO Chunks to Grow per Tick: 650
42517.11 23:00:20 [Server] INFO Zombie Aggressive Towards Villager: true
42617.11 23:00:20 [Server] INFO View Distance: 10
42717.11 23:00:20 [Server] INFO Allow Zombie Pigmen to spawn from portal blocks: true
42817.11 23:00:20 [Server] INFO Arrow Despawn Rate: 1200
42917.11 23:00:20 [Server] INFO Item Merge Radius: 2.5
43017.11 23:00:20 [Server] INFO Item Despawn Rate: 6000
43117.11 23:00:20 [Server] INFO Tile Max Tick Time: 50ms Entity max Tick Time: 50ms
43217.11 23:00:20 [Server] INFO Max TNT Explosions: 100
43317.11 23:00:20 [Server] INFO Custom Map Seeds: Village: 10387312 Feature: 14357617
43417.11 23:00:20 [Server] INFO Max Entity Collisions: 8
43517.11 23:00:20 [Server] INFO Sending up to 10 chunks per packet
43617.11 23:00:20 [Server] INFO Structure Info Saving: true
43717.11 23:00:20 [Server] INFO Random Lighting Updates: false
43817.11 23:00:20 [Server] INFO Hopper Transfer: 8 Hopper Check: 8 Hopper Amount: 1
43917.11 23:00:20 [Server] INFO Entity Tracking Range: Pl 48 / An 48 / Mo 48 / Mi 32 / Other 64
44017.11 23:00:20 [Server] INFO Entity Activation Range: An 32 / Mo 32 / Mi 16
44117.11 23:00:20 [Server] INFO NetherWart Growth Modifier: 100%
44217.11 23:00:20 [Server] INFO Wheat Growth Modifier: 100%
44317.11 23:00:20 [Server] INFO Sapling Growth Modifier: 100%
44417.11 23:00:20 [Server] INFO Pumpkin Growth Modifier: 100%
44517.11 23:00:20 [Server] INFO Mushroom Growth Modifier: 100%
44617.11 23:00:20 [Server] INFO Melon Growth Modifier: 100%
44717.11 23:00:20 [Server] INFO Cane Growth Modifier: 100%
44817.11 23:00:20 [Server] INFO Cactus Growth Modifier: 100%
44917.11 23:00:20 [Server] INFO Nerfing mobs spawned from spawners: false
45017.11 23:00:20 [Server] INFO Mob Spawn Range: 4
45117.11 23:00:20 [Server] INFO Replace Blocks: [1, 5]
45217.11 23:00:20 [Server] INFO Hidden Blocks: [14, 15, 16, 21, 48, 49, 54, 56, 73, 74, 82, 129, 130]
45317.11 23:00:20 [Server] INFO Engine Mode: 1
45417.11 23:00:20 [Server] INFO Anti X-Ray: true
45517.11 23:00:20 [Server] INFO -------- World Settings For [DonatorMines] --------
45617.11 23:00:20 [Server] INFO Loaded configuration for world 'KCells'
45717.11 23:00:20 [Server] INFO (KCells) Fire spread is UNRESTRICTED.
45817.11 23:00:20 [Server] INFO (KCells) Lava fire is blocked.
45917.11 23:00:20 [Server] INFO (KCells) Lighters are PERMITTED.
46017.11 23:00:20 [Server] INFO (KCells) TNT ignition is PERMITTED.
46117.11 23:00:20 [Server] INFO Preparing start region for level 7 (Seed: 1142451281673854906)
46217.11 23:00:20 [Server] INFO BukkitPlotGenerator does not fully support: null
46317.11 23:00:20 [Server] INFO World async lighting: false
46417.11 23:00:20 [Server] INFO Keep spawn chunk loaded: true
46517.11 23:00:20 [Server] INFO WorldServer TickNextTickList cap always processes redstone: false
46617.11 23:00:20 [Server] INFO WorldServer TickNextTick cap set at 10000
46717.11 23:00:20 [Server] INFO Allow undead horse types to be leashed: false
46817.11 23:00:20 [Server] INFO Fix TNT cannons: false
46917.11 23:00:20 [Server] INFO Water over lava flow speed: 5
47017.11 23:00:20 [Server] INFO Living Entity Despawn Ranges: Soft: 32 Hard: 128
47117.11 23:00:20 [Server] INFO Max height for cactus growth 3. Max height for reed growth 3
47217.11 23:00:20 [Server] INFO Squids will spawn between Y: 45.0 and Y: 63.0
47317.11 23:00:20 [Server] INFO Player blocking damage multiplier set to 0.5
47417.11 23:00:20 [Server] INFO Remove invalid mob spawner tile entities: true
47517.11 23:00:20 [Server] INFO -------- World Settings For [KCells] --------
47617.11 23:00:20 [Server] INFO Experience Merge Radius: 3.0
47717.11 23:00:20 [Server] INFO Clear tick list: false
47817.11 23:00:20 [Server] INFO Chunks to Grow per Tick: 650
47917.11 23:00:20 [Server] INFO Zombie Aggressive Towards Villager: true
48017.11 23:00:20 [Server] INFO View Distance: 10
48117.11 23:00:20 [Server] INFO Allow Zombie Pigmen to spawn from portal blocks: true
48217.11 23:00:20 [Server] INFO Arrow Despawn Rate: 1200
48317.11 23:00:20 [Server] INFO Item Merge Radius: 2.5
48417.11 23:00:20 [Server] INFO Item Despawn Rate: 6000
48517.11 23:00:20 [Server] INFO Tile Max Tick Time: 50ms Entity max Tick Time: 50ms
48617.11 23:00:20 [Server] INFO Max TNT Explosions: 100
48717.11 23:00:20 [Server] INFO Custom Map Seeds: Village: 10387312 Feature: 14357617
48817.11 23:00:20 [Server] INFO Max Entity Collisions: 8
48917.11 23:00:20 [Server] INFO Sending up to 10 chunks per packet
49017.11 23:00:20 [Server] INFO Structure Info Saving: true
49117.11 23:00:20 [Server] INFO Random Lighting Updates: false
49217.11 23:00:20 [Server] INFO Hopper Transfer: 8 Hopper Check: 8 Hopper Amount: 1
49317.11 23:00:20 [Server] INFO Entity Tracking Range: Pl 48 / An 48 / Mo 48 / Mi 32 / Other 64
49417.11 23:00:20 [Server] INFO Entity Activation Range: An 32 / Mo 32 / Mi 16
49517.11 23:00:20 [Server] INFO NetherWart Growth Modifier: 100%
49617.11 23:00:20 [Server] INFO Wheat Growth Modifier: 100%
49717.11 23:00:20 [Server] INFO Sapling Growth Modifier: 100%
49817.11 23:00:20 [Server] INFO Pumpkin Growth Modifier: 100%
49917.11 23:00:20 [Server] INFO Mushroom Growth Modifier: 100%
50017.11 23:00:20 [Server] INFO Melon Growth Modifier: 100%
50117.11 23:00:20 [Server] INFO Cane Growth Modifier: 100%
50217.11 23:00:20 [Server] INFO Cactus Growth Modifier: 100%
50317.11 23:00:20 [Server] INFO Nerfing mobs spawned from spawners: false
50417.11 23:00:20 [Server] INFO Mob Spawn Range: 4
50517.11 23:00:20 [Server] INFO Replace Blocks: [1, 5]
50617.11 23:00:20 [Server] INFO Hidden Blocks: [14, 15, 16, 21, 48, 49, 54, 56, 73, 74, 82, 129, 130]
50717.11 23:00:20 [Server] INFO Engine Mode: 1
50817.11 23:00:20 [Server] INFO Anti X-Ray: true
50917.11 23:00:20 [Server] INFO -------- World Settings For [KCells] --------
51017.11 23:00:20 [Server] INFO Loaded configuration for world 'Plots'
51117.11 23:00:20 [Server] INFO (Plots) Fire spread is UNRESTRICTED.
51217.11 23:00:20 [Server] INFO (Plots) Lava fire is blocked.
51317.11 23:00:20 [Server] INFO (Plots) Lighters are PERMITTED.
51417.11 23:00:20 [Server] INFO (Plots) TNT ignition is PERMITTED.
51517.11 23:00:20 [Server] INFO UUID of player jbhjbh10 is c3a586de-c61b-4771-8f46-d42f1eb6e14e
51617.11 23:00:19 [Server] INFO Preparing start region for level 6 (Seed: -3923316417460837253)
51717.11 23:00:19 [Server] INFO World possibly already loaded: Plots
51817.11 23:00:19 [Server] INFO - schematic: false
51917.11 23:00:19 [Server] INFO - manager: com.intellectualcrafters.plot.generator.HybridPlotManager
52017.11 23:00:19 [Server] INFO - plotworld: com.intellectualcrafters.plot.generator.HybridPlotWorld
52117.11 23:00:19 [Server] INFO - generator: PlotSquared>PlotSquared
52217.11 23:00:19 [Server] INFO Detected world load for 'Plots'
52317.11 23:00:19 [Server] INFO World async lighting: false
52417.11 23:00:19 [Server] INFO Keep spawn chunk loaded: true
52517.11 23:00:19 [Server] INFO WorldServer TickNextTickList cap always processes redstone: false
52617.11 23:00:19 [Server] INFO WorldServer TickNextTick cap set at 10000
52717.11 23:00:19 [Server] INFO Allow undead horse types to be leashed: false
52817.11 23:00:19 [Server] INFO Fix TNT cannons: false
52917.11 23:00:19 [Server] INFO Water over lava flow speed: 5
53017.11 23:00:19 [Server] INFO Living Entity Despawn Ranges: Soft: 32 Hard: 128
53117.11 23:00:19 [Server] INFO Max height for cactus growth 3. Max height for reed growth 3
53217.11 23:00:19 [Server] INFO Squids will spawn between Y: 45.0 and Y: 63.0
53317.11 23:00:19 [Server] INFO Player blocking damage multiplier set to 0.5
53417.11 23:00:19 [Server] INFO Remove invalid mob spawner tile entities: true
53517.11 23:00:19 [Server] INFO -------- World Settings For [Plots] --------
53617.11 23:00:19 [Server] INFO Experience Merge Radius: 3.0
53717.11 23:00:19 [Server] INFO Clear tick list: false
53817.11 23:00:19 [Server] INFO Chunks to Grow per Tick: 650
53917.11 23:00:19 [Server] INFO Zombie Aggressive Towards Villager: true
54017.11 23:00:19 [Server] INFO View Distance: 10
54117.11 23:00:19 [Server] INFO Allow Zombie Pigmen to spawn from portal blocks: true
54217.11 23:00:19 [Server] INFO Arrow Despawn Rate: 1200
54317.11 23:00:19 [Server] INFO Item Merge Radius: 2.5
54417.11 23:00:19 [Server] INFO Item Despawn Rate: 6000
54517.11 23:00:19 [Server] INFO Tile Max Tick Time: 50ms Entity max Tick Time: 50ms
54617.11 23:00:19 [Server] INFO Max TNT Explosions: 100
54717.11 23:00:19 [Server] INFO Custom Map Seeds: Village: 10387312 Feature: 14357617
54817.11 23:00:19 [Server] INFO Max Entity Collisions: 8
54917.11 23:00:19 [Server] INFO Sending up to 10 chunks per packet
55017.11 23:00:19 [Server] INFO Structure Info Saving: true
55117.11 23:00:19 [Server] INFO Random Lighting Updates: false
55217.11 23:00:19 [Server] INFO Hopper Transfer: 8 Hopper Check: 8 Hopper Amount: 1
55317.11 23:00:19 [Server] INFO Entity Tracking Range: Pl 48 / An 48 / Mo 48 / Mi 32 / Other 64
55417.11 23:00:19 [Server] INFO Entity Activation Range: An 32 / Mo 32 / Mi 16
55517.11 23:00:19 [Server] INFO NetherWart Growth Modifier: 100%
55617.11 23:00:19 [Server] INFO Wheat Growth Modifier: 100%
55717.11 23:00:19 [Server] INFO Sapling Growth Modifier: 100%
55817.11 23:00:19 [Server] INFO Pumpkin Growth Modifier: 100%
55917.11 23:00:19 [Server] INFO Mushroom Growth Modifier: 100%
56017.11 23:00:19 [Server] INFO Melon Growth Modifier: 100%
56117.11 23:00:19 [Server] INFO Cane Growth Modifier: 100%
56217.11 23:00:19 [Server] INFO Cactus Growth Modifier: 100%
56317.11 23:00:19 [Server] INFO Nerfing mobs spawned from spawners: false
56417.11 23:00:19 [Server] INFO Mob Spawn Range: 4
56517.11 23:00:19 [Server] INFO Replace Blocks: [1, 5]
56617.11 23:00:19 [Server] INFO Hidden Blocks: [14, 15, 16, 21, 48, 49, 54, 56, 73, 74, 82, 129, 130]
56717.11 23:00:19 [Server] INFO Engine Mode: 1
56817.11 23:00:19 [Server] INFO Anti X-Ray: true
56917.11 23:00:19 [Server] INFO -------- World Settings For [Plots] --------
57017.11 23:00:19 [Server] INFO Loaded configuration for world 'Plot'
57117.11 23:00:19 [Server] INFO (Plot) Fire spread is UNRESTRICTED.
57217.11 23:00:19 [Server] INFO (Plot) Lava fire is blocked.
57317.11 23:00:19 [Server] INFO (Plot) Lighters are PERMITTED.
57417.11 23:00:19 [Server] INFO (Plot) TNT ignition is PERMITTED.
57517.11 23:00:19 [Server] INFO Preparing start region for level 5 (Seed: -2424258649534453064)
57617.11 23:00:19 [Server] INFO World possibly already loaded: Plot
57717.11 23:00:19 [Server] INFO - schematic: false
57817.11 23:00:19 [Server] INFO - manager: com.intellectualcrafters.plot.generator.HybridPlotManager
57917.11 23:00:19 [Server] INFO - plotworld: com.intellectualcrafters.plot.generator.HybridPlotWorld
58017.11 23:00:19 [Server] INFO - generator: PlotSquared>PlotSquared
58117.11 23:00:19 [Server] INFO Detected world load for 'Plot'
58217.11 23:00:19 [Server] INFO World async lighting: false
58317.11 23:00:19 [Server] INFO Keep spawn chunk loaded: true
58417.11 23:00:19 [Server] INFO WorldServer TickNextTickList cap always processes redstone: false
58517.11 23:00:19 [Server] INFO WorldServer TickNextTick cap set at 10000
58617.11 23:00:19 [Server] INFO Allow undead horse types to be leashed: false
58717.11 23:00:19 [Server] INFO Fix TNT cannons: false
58817.11 23:00:19 [Server] INFO Water over lava flow speed: 5
58917.11 23:00:19 [Server] INFO Living Entity Despawn Ranges: Soft: 32 Hard: 128
59017.11 23:00:19 [Server] INFO Max height for cactus growth 3. Max height for reed growth 3
59117.11 23:00:19 [Server] INFO Squids will spawn between Y: 45.0 and Y: 63.0
59217.11 23:00:19 [Server] INFO Player blocking damage multiplier set to 0.5
59317.11 23:00:19 [Server] INFO Remove invalid mob spawner tile entities: true
59417.11 23:00:19 [Server] INFO -------- World Settings For [Plot] --------
59517.11 23:00:19 [Server] INFO Experience Merge Radius: 3.0
59617.11 23:00:19 [Server] INFO Clear tick list: false
59717.11 23:00:19 [Server] INFO Chunks to Grow per Tick: 650
59817.11 23:00:19 [Server] INFO Zombie Aggressive Towards Villager: true
59917.11 23:00:19 [Server] INFO View Distance: 10
60017.11 23:00:19 [Server] INFO Allow Zombie Pigmen to spawn from portal blocks: true
60117.11 23:00:19 [Server] INFO Arrow Despawn Rate: 1200
60217.11 23:00:19 [Server] INFO Item Merge Radius: 2.5
60317.11 23:00:19 [Server] INFO Item Despawn Rate: 6000
60417.11 23:00:19 [Server] INFO Tile Max Tick Time: 50ms Entity max Tick Time: 50ms
60517.11 23:00:19 [Server] INFO Max TNT Explosions: 100
60617.11 23:00:19 [Server] INFO Custom Map Seeds: Village: 10387312 Feature: 14357617
60717.11 23:00:19 [Server] INFO Max Entity Collisions: 8
60817.11 23:00:19 [Server] INFO Sending up to 10 chunks per packet
60917.11 23:00:19 [Server] INFO Structure Info Saving: true
61017.11 23:00:19 [Server] INFO Random Lighting Updates: false
61117.11 23:00:19 [Server] INFO Hopper Transfer: 8 Hopper Check: 8 Hopper Amount: 1
61217.11 23:00:19 [Server] INFO Entity Tracking Range: Pl 48 / An 48 / Mo 48 / Mi 32 / Other 64
61317.11 23:00:19 [Server] INFO Entity Activation Range: An 32 / Mo 32 / Mi 16
61417.11 23:00:19 [Server] INFO NetherWart Growth Modifier: 100%
61517.11 23:00:19 [Server] INFO Wheat Growth Modifier: 100%
61617.11 23:00:19 [Server] INFO Sapling Growth Modifier: 100%
61717.11 23:00:19 [Server] INFO Pumpkin Growth Modifier: 100%
61817.11 23:00:19 [Server] INFO Mushroom Growth Modifier: 100%
61917.11 23:00:19 [Server] INFO Melon Growth Modifier: 100%
62017.11 23:00:19 [Server] INFO Cane Growth Modifier: 100%
62117.11 23:00:19 [Server] INFO Cactus Growth Modifier: 100%
62217.11 23:00:19 [Server] INFO Nerfing mobs spawned from spawners: false
62317.11 23:00:19 [Server] INFO Mob Spawn Range: 4
62417.11 23:00:19 [Server] INFO Replace Blocks: [1, 5]
62517.11 23:00:19 [Server] INFO Hidden Blocks: [14, 15, 16, 21, 48, 49, 54, 56, 73, 74, 82, 129, 130]
62617.11 23:00:19 [Server] INFO Engine Mode: 1
62717.11 23:00:19 [Server] INFO Anti X-Ray: true
62817.11 23:00:19 [Server] INFO -------- World Settings For [Plot] --------
62917.11 23:00:19 [Server] INFO Loaded configuration for world 'MobArena'
63017.11 23:00:19 [Server] INFO (MobArena) Fire spread is UNRESTRICTED.
63117.11 23:00:19 [Server] INFO (MobArena) Lava fire is blocked.
63217.11 23:00:19 [Server] INFO (MobArena) Lighters are PERMITTED.
63317.11 23:00:19 [Server] INFO (MobArena) TNT ignition is PERMITTED.
63417.11 23:00:18 [Server] INFO Preparing start region for level 4 (Seed: -329594961889396017)
63517.11 23:00:18 [Server] INFO BukkitPlotGenerator does not fully support: null
63617.11 23:00:18 [Server] INFO World async lighting: false
63717.11 23:00:18 [Server] INFO Keep spawn chunk loaded: true
63817.11 23:00:18 [Server] INFO WorldServer TickNextTickList cap always processes redstone: false
63917.11 23:00:18 [Server] INFO WorldServer TickNextTick cap set at 10000
64017.11 23:00:18 [Server] INFO Allow undead horse types to be leashed: false
64117.11 23:00:18 [Server] INFO Fix TNT cannons: false
64217.11 23:00:18 [Server] INFO Water over lava flow speed: 5
64317.11 23:00:18 [Server] INFO Living Entity Despawn Ranges: Soft: 32 Hard: 128
64417.11 23:00:18 [Server] INFO Max height for cactus growth 3. Max height for reed growth 3
64517.11 23:00:18 [Server] INFO Squids will spawn between Y: 45.0 and Y: 63.0
64617.11 23:00:18 [Server] INFO Player blocking damage multiplier set to 0.5
64717.11 23:00:18 [Server] INFO Remove invalid mob spawner tile entities: true
64817.11 23:00:18 [Server] INFO -------- World Settings For [MobArena] --------
64917.11 23:00:18 [Server] INFO Experience Merge Radius: 3.0
65017.11 23:00:18 [Server] INFO Clear tick list: false
65117.11 23:00:18 [Server] INFO Chunks to Grow per Tick: 650
65217.11 23:00:18 [Server] INFO Zombie Aggressive Towards Villager: true
65317.11 23:00:18 [Server] INFO View Distance: 10
65417.11 23:00:18 [Server] INFO Allow Zombie Pigmen to spawn from portal blocks: true
65517.11 23:00:18 [Server] INFO Arrow Despawn Rate: 1200
65617.11 23:00:18 [Server] INFO Item Merge Radius: 2.5
65717.11 23:00:18 [Server] INFO Item Despawn Rate: 6000
65817.11 23:00:18 [Server] INFO Tile Max Tick Time: 50ms Entity max Tick Time: 50ms
65917.11 23:00:18 [Server] INFO Max TNT Explosions: 100
66017.11 23:00:18 [Server] INFO Custom Map Seeds: Village: 10387312 Feature: 14357617
66117.11 23:00:18 [Server] INFO Max Entity Collisions: 8
66217.11 23:00:18 [Server] INFO Sending up to 10 chunks per packet
66317.11 23:00:18 [Server] INFO Structure Info Saving: true
66417.11 23:00:18 [Server] INFO Random Lighting Updates: false
66517.11 23:00:18 [Server] INFO Hopper Transfer: 8 Hopper Check: 8 Hopper Amount: 1
66617.11 23:00:18 [Server] INFO Entity Tracking Range: Pl 48 / An 48 / Mo 48 / Mi 32 / Other 64
66717.11 23:00:18 [Server] INFO Entity Activation Range: An 32 / Mo 32 / Mi 16
66817.11 23:00:18 [Server] INFO NetherWart Growth Modifier: 100%
66917.11 23:00:18 [Server] INFO Wheat Growth Modifier: 100%
67017.11 23:00:18 [Server] INFO Sapling Growth Modifier: 100%
67117.11 23:00:18 [Server] INFO Pumpkin Growth Modifier: 100%
67217.11 23:00:18 [Server] INFO Mushroom Growth Modifier: 100%
67317.11 23:00:18 [Server] INFO Melon Growth Modifier: 100%
67417.11 23:00:18 [Server] INFO Cane Growth Modifier: 100%
67517.11 23:00:18 [Server] INFO Cactus Growth Modifier: 100%
67617.11 23:00:18 [Server] INFO Nerfing mobs spawned from spawners: false
67717.11 23:00:18 [Server] INFO Mob Spawn Range: 4
67817.11 23:00:18 [Server] INFO Replace Blocks: [1, 5]
67917.11 23:00:18 [Server] INFO Hidden Blocks: [14, 15, 16, 21, 48, 49, 54, 56, 73, 74, 82, 129, 130]
68017.11 23:00:18 [Server] INFO Engine Mode: 1
68117.11 23:00:18 [Server] INFO Anti X-Ray: true
68217.11 23:00:18 [Server] INFO -------- World Settings For [MobArena] --------
68317.11 23:00:18 [Server] INFO Loaded configuration for world 'Yard'
68417.11 23:00:18 [Server] INFO (Yard) Fire spread is UNRESTRICTED.
68517.11 23:00:18 [Server] INFO (Yard) Lava fire is blocked.
68617.11 23:00:18 [Server] INFO (Yard) Lighters are PERMITTED.
68717.11 23:00:18 [Server] INFO (Yard) TNT ignition is PERMITTED.
68817.11 23:00:18 [Server] INFO Preparing start region for level 3 (Seed: 3071817848873016885)
68917.11 23:00:18 [Server] INFO BukkitPlotGenerator does not fully support: null
69017.11 23:00:18 [Server] INFO World async lighting: false
69117.11 23:00:18 [Server] INFO Keep spawn chunk loaded: true
69217.11 23:00:18 [Server] INFO WorldServer TickNextTickList cap always processes redstone: false
69317.11 23:00:18 [Server] INFO WorldServer TickNextTick cap set at 10000
69417.11 23:00:18 [Server] INFO Allow undead horse types to be leashed: false
69517.11 23:00:18 [Server] INFO Fix TNT cannons: false
69617.11 23:00:18 [Server] INFO Water over lava flow speed: 5
69717.11 23:00:18 [Server] INFO Living Entity Despawn Ranges: Soft: 32 Hard: 128
69817.11 23:00:18 [Server] INFO Max height for cactus growth 3. Max height for reed growth 3
69917.11 23:00:18 [Server] INFO Squids will spawn between Y: 45.0 and Y: 63.0
70017.11 23:00:18 [Server] INFO Player blocking damage multiplier set to 0.5
70117.11 23:00:18 [Server] INFO Remove invalid mob spawner tile entities: true
70217.11 23:00:18 [Server] INFO -------- World Settings For [Yard] --------
70317.11 23:00:18 [Server] INFO Experience Merge Radius: 3.0
70417.11 23:00:18 [Server] INFO Clear tick list: false
70517.11 23:00:18 [Server] INFO Chunks to Grow per Tick: 650
70617.11 23:00:18 [Server] INFO Zombie Aggressive Towards Villager: true
70717.11 23:00:18 [Server] INFO View Distance: 10
70817.11 23:00:18 [Server] INFO Allow Zombie Pigmen to spawn from portal blocks: true
70917.11 23:00:18 [Server] INFO Arrow Despawn Rate: 1200
71017.11 23:00:18 [Server] INFO Item Merge Radius: 2.5
71117.11 23:00:18 [Server] INFO Item Despawn Rate: 6000
71217.11 23:00:18 [Server] INFO Tile Max Tick Time: 50ms Entity max Tick Time: 50ms
71317.11 23:00:18 [Server] INFO Max TNT Explosions: 100
71417.11 23:00:18 [Server] INFO Custom Map Seeds: Village: 10387312 Feature: 14357617
71517.11 23:00:18 [Server] INFO Max Entity Collisions: 8
71617.11 23:00:18 [Server] INFO Sending up to 10 chunks per packet
71717.11 23:00:18 [Server] INFO Structure Info Saving: true
71817.11 23:00:18 [Server] INFO Random Lighting Updates: false
71917.11 23:00:18 [Server] INFO Hopper Transfer: 8 Hopper Check: 8 Hopper Amount: 1
72017.11 23:00:18 [Server] INFO Entity Tracking Range: Pl 48 / An 48 / Mo 48 / Mi 32 / Other 64
72117.11 23:00:18 [Server] INFO Entity Activation Range: An 32 / Mo 32 / Mi 16
72217.11 23:00:18 [Server] INFO NetherWart Growth Modifier: 100%
72317.11 23:00:18 [Server] INFO Wheat Growth Modifier: 100%
72417.11 23:00:18 [Server] INFO Sapling Growth Modifier: 100%
72517.11 23:00:18 [Server] INFO Pumpkin Growth Modifier: 100%
72617.11 23:00:18 [Server] INFO Mushroom Growth Modifier: 100%
72717.11 23:00:18 [Server] INFO Melon Growth Modifier: 100%
72817.11 23:00:18 [Server] INFO Cane Growth Modifier: 100%
72917.11 23:00:18 [Server] INFO Cactus Growth Modifier: 100%
73017.11 23:00:18 [Server] INFO Nerfing mobs spawned from spawners: false
73117.11 23:00:18 [Server] INFO Mob Spawn Range: 4
73217.11 23:00:18 [Server] INFO Replace Blocks: [1, 5]
73317.11 23:00:18 [Server] INFO Hidden Blocks: [14, 15, 16, 21, 48, 49, 54, 56, 73, 74, 82, 129, 130]
73417.11 23:00:18 [Server] INFO Engine Mode: 1
73517.11 23:00:18 [Server] INFO Anti X-Ray: true
73617.11 23:00:18 [Server] INFO -------- World Settings For [Yard] --------
73717.11 23:00:18 [Server] WARN Use '/mv remove' to remove it from the config!
73817.11 23:00:18 [Server] WARN WorldManager: Can't load this world because the folder was deleted/moved: Prison
73917.11 23:00:18 [Server] INFO Enabling Multiverse-Core v2.5.0-b727
74017.11 23:00:18 [Server] INFO Enabling Banknotes v1.8.0
74117.11 23:00:18 [Server] INFO 1 rankup cost multipliers loaded!
74217.11 23:00:18 [Server] INFO 1 rankup cost discounts loaded!
74317.11 23:00:18 [Server] INFO 26 Ranks loaded with 25 unique RankUps!
74417.11 23:00:18 [Server] INFO Loading EZRanksLite messages.yml
74517.11 23:00:18 [Server] ERROR EZRanksLite hooked into Essentials!!
74617.11 23:00:18 [Server] ERROR EZRanksLite hooked into VoteParty!!
74717.11 23:00:18 [Server] INFO Enabling EZRanksLite vv1.6
74817.11 23:00:18 [Server] WARN Using After v1_8 (v1_8_R3) Fanciful Library!
74917.11 23:00:18 [Server] WARN Found Vault v1.5.6-b49 for chat hook.
75017.11 23:00:18 [Server] INFO Enabling LinkItem v1.0-STABLE
75117.11 23:00:17 [Server] INFO Enabling ShopGUIPlus v1.3.3
75217.11 23:00:17 [Server] INFO Enabling EssentialsSpawn vTeamCity
75317.11 23:00:17 [Server] INFO Enabling PlayerVaults v3.5.7-b${BUILD_NUMBER}
75417.11 23:00:17 [Server] INFO Enabling EssentialsProtect vTeamCity
75517.11 23:00:17 [Server] INFO An update is available, download it from spigot!
75617.11 23:00:17 [Server] INFO Enabling ActionAPI v1.1.3
75717.11 23:00:17 [Server] INFO Enabling AuctionHouse v3.3
75817.11 23:00:17 [Server] INFO Loading region data...
75917.11 23:00:17 [Server] INFO Loaded configuration for world 'world_the_end'
76017.11 23:00:17 [Server] INFO (world_the_end) Fire spread is UNRESTRICTED.
76117.11 23:00:17 [Server] INFO (world_the_end) Lava fire is blocked.
76217.11 23:00:17 [Server] INFO (world_the_end) Lighters are PERMITTED.
76317.11 23:00:17 [Server] INFO (world_the_end) TNT ignition is PERMITTED.
76417.11 23:00:17 [Server] INFO Loaded configuration for world 'world_nether'
76517.11 23:00:17 [Server] INFO (world_nether) Fire spread is UNRESTRICTED.
76617.11 23:00:17 [Server] INFO (world_nether) Lava fire is blocked.
76717.11 23:00:17 [Server] INFO (world_nether) Lighters are PERMITTED.
76817.11 23:00:17 [Server] INFO (world_nether) TNT ignition is PERMITTED.
76917.11 23:00:17 [Server] INFO Loaded configuration for world 'world'
77017.11 23:00:17 [Server] INFO (world) Fire spread is UNRESTRICTED.
77117.11 23:00:17 [Server] INFO (world) Lava fire is blocked.
77217.11 23:00:17 [Server] INFO (world) Lighters are PERMITTED.
77317.11 23:00:17 [Server] INFO (world) TNT ignition is PERMITTED.
77417.11 23:00:17 [Server] INFO Enabling WorldGuard v6.1.3-SNAPSHOT;c904242
77517.11 23:00:17 [Server] INFO ---------------------------
77617.11 23:00:17 [Server] INFO Download at http://www.spigotmc.org/resources/voteparty.987/
77717.11 23:00:17 [Server] INFO You are running 1.3.4.3
77817.11 23:00:17 [Server] INFO VoteParty 1.11.0
77917.11 23:00:17 [Server] INFO An update for VoteParty has been found!
78017.11 23:00:17 [Server] INFO VoteParty Updater
78117.11 23:00:17 [Server] INFO ---------------------------
78217.11 23:00:17 [Server] INFO Enabling VoteParty v1.3.4.3
78317.11 23:00:16 [Server] INFO Votifier plugin found, enabling Votifier support.
78417.11 23:00:16 [Server] WARN Economy plugin is not enabled.
78517.11 23:00:16 [Server] INFO Couldn't find the TuxTwoLib plugin. Only able to give items to online players only.
78617.11 23:00:16 [Server] INFO MC 1.7.2 or above found, enabling version 2 log handling.
78717.11 23:00:16 [Server] INFO MC 1.3 or above found, enabling version 2 XP handling.
78817.11 23:00:16 [Server] INFO Enabling EnjinMinecraftPlugin v2.7.8-bukkit
78917.11 23:00:16 [Server] INFO GAListener v1.3.1 Enabled
79017.11 23:00:16 [Server] INFO Enabling GAListener v1.3.1
79117.11 23:00:16 [Server] ERROR The plugin will not work when using this plugin
79217.11 23:00:16 [Server] ERROR You are using the NameTagEdit plugin
79317.11 23:00:16 [Server] INFO Adding command 'featherboard'
79417.11 23:00:16 [Server] INFO Toggle persistence is disabled!
79517.11 23:00:16 [Server] INFO A new update for FeatherBoard is available for download on Spigot!
79617.11 23:00:16 [Server] INFO Loading language file: lang_en
79717.11 23:00:16 [Server] INFO Loading messages ...
79817.11 23:00:16 [Server] INFO Adding scoreboard group 'towny-town-example' ...
79917.11 23:00:16 [Server] INFO Adding scoreboard group 'mcmmo-levelup' ...
80017.11 23:00:16 [Server] INFO Adding scoreboard group 'combat-scoreboard-example' ...
80117.11 23:00:16 [Server] INFO Adding scoreboard group 'default' ...
80217.11 23:00:16 [Server] INFO Arguments: 1
80317.11 23:00:16 [Server] INFO Lines: 2
80417.11 23:00:16 [Server] INFO Creating new custom effect: warning
80517.11 23:00:16 [Server] INFO Loading event hook: Vanilla Combat hook ...
80617.11 23:00:16 [Server] INFO Loading event hook: Vanilla player first join ...
80717.11 23:00:16 [Server] INFO Loading event hook: Vanilla player rejoin ...
80817.11 23:00:16 [Server] INFO Loading event hook: Vanilla player join ...
80917.11 23:00:16 [Server] INFO Loading event hook: Vanilla Create portal hook ...
81017.11 23:00:16 [Server] INFO Loading event hook: Vanilla Block place hook ...
81117.11 23:00:16 [Server] INFO Loading event hook: Vanilla Block break hook ...
81217.11 23:00:16 [Server] INFO Loading event hook: Vanilla Death hook ...
81317.11 23:00:16 [Server] INFO Loading event hook: MobArena ...
81417.11 23:00:16 [Server] INFO Loading event hook: ChatReaction start event ...
81517.11 23:00:16 [Server] INFO Loading Event hooks ...
81617.11 23:00:16 [Server] INFO Loaded 2031 of the 4736 placholders
81717.11 23:00:15 [Server] INFO Loading placeholders ...
81817.11 23:00:15 [Server] INFO Loading configuration ...
81917.11 23:00:15 [Server] INFO -=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-
82017.11 23:00:15 [Server] INFO Site: http://www.mvdw-software.com/
82117.11 23:00:15 [Server] INFO Author: Maximvdw (Maxim Van de Wynckel)
82217.11 23:00:15 [Server] INFO Framework version: 2016-11
82317.11 23:00:15 [Server] INFO Plugin: FeatherBoard v3.15.0
82417.11 23:00:15 [Server] INFO -=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-
82517.11 23:00:15 [Server] INFO Enabling FeatherBoard v3.15.0
82617.11 23:00:15 [Server] INFO Essentials: Using PermissionsEx based permissions.
82717.11 23:00:15 [Server] INFO [Vault][Chat] PermissionsEx_Chat hooked.
82817.11 23:00:15 [Server] INFO [Vault][Permission] PermissionsEx hooked.
82917.11 23:00:15 [Server] INFO WEPIF: PermissionsEx detected! Using PermissionsEx for permissions.
83017.11 23:00:15 [Server] INFO Permissions file successfully reloaded
83117.11 23:00:15 [Server] INFO Initializing file backend
83217.11 23:00:15 [Server] INFO Enabling PermissionsEx v1.23.4
83317.11 23:00:15 [Server] INFO Enabling EssentialsChat vTeamCity
83417.11 23:00:15 [Server] INFO Enabling Vouchers v2.1.0
83517.11 23:00:15 [Server] INFO Votifier enabled.
83617.11 23:00:15 [Server] INFO Enabling Votifier v1.8
83717.11 23:00:15 [Server] INFO []================================[]
83817.11 23:00:15 [Server] INFO | You have the newest version
83917.11 23:00:15 [Server] INFO | Update:
84017.11 23:00:15 [Server] INFO | Mail: Leoko4433@gmail.com
84117.11 23:00:15 [Server] INFO | Skype: Leoko33
84217.11 23:00:15 [Server] INFO | Support:
84317.11 23:00:15 [Server] INFO | Storage: HSQLDB (local)
84417.11 23:00:15 [Server] INFO | Version: 2.1.3-RELEASE
84517.11 23:00:15 [Server] INFO | Developer: Leoko
84617.11 23:00:15 [Server] INFO | Name: AdvancedBan
84717.11 23:00:15 [Server] INFO | Information:
84817.11 23:00:15 [Server] INFO []=====[Enabling AdvancedBan]=====[]
84917.11 23:00:14 [Server] INFO Skype: Leoko33
85017.11 23:00:14 [Server] INFO Check your MySQL.yml
85117.11 23:00:14 [Server] INFO Disabling plugin!
85217.11 23:00:14 [Server] INFO Could not connect to MySQL-Server!
85317.11 23:00:14 [Server] INFO MySQL-Error
85417.11 23:00:14 [Server] INFO AdvancedBan <>
85517.11 23:00:12 [Server] INFO UUID of player FreeZe_YT is 3e2d0706-3c59-4023-882e-cb26c5ba72ce
85617.11 23:00:10 [Server] INFO No updates found!
85717.11 23:00:10 [Server] INFO Enabling AdvancedBan v2.1.3-RELEASE
85817.11 23:00:10 [Server] INFO Enabling Hub v1.5
85917.11 23:00:10 [Server] INFO enabled
86017.11 23:00:10 [Server] INFO Enabling UnbreakableEquip v1.0
86117.11 23:00:10 [Server] INFO Checking for updates compatible with your bukkit version [1.8]...
86217.11 23:00:10 [Server] INFO Clearlag is now enabled!
86317.11 23:00:10 [Server] INFO Modules have been loaded!
86417.11 23:00:10 [Server] INFO Modules enabed, loading config values
86517.11 23:00:10 [Server] INFO Loading modules...
86617.11 23:00:10 [Server] INFO Enabling ClearLag v2.9.7
86717.11 23:00:10 [Server] INFO Permissions listed in as player-commands will be given to all users.
86817.11 23:00:10 [Server] INFO Essentials: Using config file enhanced permissions.
86917.11 23:00:10 [Server] INFO [Vault][Economy] Essentials Economy hooked.
87017.11 23:00:10 [Server] INFO Using locale en_US
87117.11 23:00:10 [Server] INFO Using locale en_US
87217.11 23:00:10 [Server] INFO 1.8.8-R0.1-SNAPSHOT
87317.11 23:00:10 [Server] INFO git-PaperSpigot-443 (MC: 1.8.8)
87417.11 23:00:10 [Server] INFO Bukkit version format changed. Version not checked.
87517.11 23:00:10 [Server] INFO Enabling Essentials vTeamCity
87617.11 23:00:10 [Server] INFO Using com.sk89q.worldedit.bukkit.adapter.impl.Spigot_v1_8_R3 as the Bukkit adapter
87717.11 23:00:10 [Server] INFO WEPIF: Using the Bukkit Permissions API.
87817.11 23:00:10 [Server] INFO Enabling WorldEdit v6.1.8-SNAPSHOT;cd4729f
87917.11 23:00:10 [Server] INFO Disabling CoreProtect v2.14.2
88017.11 23:00:10 [Server] INFO CoreProtect was unable to start.
88117.11 23:00:10 [Server] INFO Spigot 1.11 or higher is required.
88217.11 23:00:10 [Server] INFO Enabling CoreProtect v2.14.2
88317.11 23:00:10 [Server] INFO nop
88417.11 23:00:10 [Server] INFO Enabling ChatColor v6.2
88517.11 23:00:10 [Server] INFO Enabling Auto_Pickup v1.9
88617.11 23:00:10 [Server] INFO Tablist> Tablist v1.3.2.9 enabled!!
88717.11 23:00:10 [Server] INFO Tablist> You have to install PlaceholderAPI to use some placeholders !
88817.11 23:00:10 [Server] INFO Enabling Tablist v1.3.2.9
88917.11 23:00:10 [Server] INFO Enabling Bounty v1.8
89017.11 23:00:10 [Server] INFO Enabling ViaVersion v1.3.0
89117.11 23:00:10 [Server] INFO ----------------------------
89217.11 23:00:10 [Server] INFO of DeluxeTags!
89317.11 23:00:10 [Server] INFO The latest version
89417.11 23:00:10 [Server] INFO You are running 1.7.1
89517.11 23:00:10 [Server] INFO DeluxeTags Updater
89617.11 23:00:10 [Server] INFO ----------------------------
89717.11 23:00:09 [Server] INFO DeluxeTags will listen to the AsyncPlayerChatEvent to provide compatibility for some chat plugins.
89817.11 23:00:09 [Server] INFO You are not using DeluxeChat!
89917.11 23:00:09 [Server] INFO Loading DeluxeTags messages.yml
90017.11 23:00:09 [Server] INFO 18 tags loaded
90117.11 23:00:09 [Server] INFO Enabling DeluxeTags v1.7.1
90217.11 23:00:09 [Server] INFO ---------------------------
90317.11 23:00:09 [Server] INFO Download at http://www.spigotmc.org/resources/chatreaction.3748/
90417.11 23:00:09 [Server] INFO You are running 1.6.2
90517.11 23:00:09 [Server] INFO ChatReaction 1.7.1
90617.11 23:00:09 [Server] INFO An update for ChatReaction has been found!
90717.11 23:00:09 [Server] INFO ChatReaction Updater
90817.11 23:00:09 [Server] INFO ---------------------------
90917.11 23:00:09 [Server] INFO Reaction stats are disabled!!
91017.11 23:00:09 [Server] INFO 48 words loaded!
91117.11 23:00:09 [Server] INFO You are using Spigot! Tooltips in reaction start messages are enabled!
91217.11 23:00:09 [Server] INFO Enabling ChatReaction v1.6.2
91317.11 23:00:09 [Server] INFO Enabling CoinFlip vBETA 0.1
91417.11 23:00:09 [Server] INFO Found PermissionsEx! Hooking in.
91517.11 23:00:09 [Server] INFO Enabling NametagEdit v4.1.7
91617.11 23:00:09 [Server] INFO Enabling PlugMan v2.1.4
91717.11 23:00:09 [Server] INFO Could not find BossBarAPI!
91817.11 23:00:09 [Server] INFO ClearChat version 1.2 by Luconian activated
91917.11 23:00:09 [Server] INFO Enabling ClearChat v1.2
92017.11 23:00:09 [Server] INFO Enabling SimpleBroadcast v1.9.2
92117.11 23:00:09 [Server] INFO Preparing start region for level 2 (Seed: -8036449300263837755)
92217.11 23:00:08 [Server] INFO Preparing start region for level 1 (Seed: -8036449300263837755)
92317.11 23:00:08 [Server] INFO Preparing start region for level 0 (Seed: -5855752272977081121)
92417.11 23:00:08 [Server] INFO BukkitPlotGenerator does not fully support: null
92517.11 23:00:08 [Server] INFO World async lighting: false
92617.11 23:00:08 [Server] INFO Keep spawn chunk loaded: true
92717.11 23:00:08 [Server] INFO WorldServer TickNextTickList cap always processes redstone: false
92817.11 23:00:08 [Server] INFO WorldServer TickNextTick cap set at 10000
92917.11 23:00:08 [Server] INFO Allow undead horse types to be leashed: false
93017.11 23:00:08 [Server] INFO Fix TNT cannons: false
93117.11 23:00:08 [Server] INFO Water over lava flow speed: 5
93217.11 23:00:08 [Server] INFO Living Entity Despawn Ranges: Soft: 32 Hard: 128
93317.11 23:00:08 [Server] INFO Max height for cactus growth 3. Max height for reed growth 3
93417.11 23:00:08 [Server] INFO Squids will spawn between Y: 45.0 and Y: 63.0
93517.11 23:00:08 [Server] INFO Player blocking damage multiplier set to 0.5
93617.11 23:00:08 [Server] INFO Remove invalid mob spawner tile entities: true
93717.11 23:00:08 [Server] INFO -------- World Settings For [world_the_end] --------
93817.11 23:00:08 [Server] INFO Experience Merge Radius: 3.0
93917.11 23:00:08 [Server] INFO Clear tick list: false
94017.11 23:00:08 [Server] INFO Chunks to Grow per Tick: 650
94117.11 23:00:08 [Server] INFO Zombie Aggressive Towards Villager: true
94217.11 23:00:08 [Server] INFO View Distance: 10
94317.11 23:00:08 [Server] INFO Allow Zombie Pigmen to spawn from portal blocks: true
94417.11 23:00:08 [Server] INFO Arrow Despawn Rate: 1200
94517.11 23:00:08 [Server] INFO Item Merge Radius: 2.5
94617.11 23:00:08 [Server] INFO Item Despawn Rate: 6000
94717.11 23:00:08 [Server] INFO Tile Max Tick Time: 50ms Entity max Tick Time: 50ms
94817.11 23:00:08 [Server] INFO Max TNT Explosions: 100
94917.11 23:00:08 [Server] INFO Custom Map Seeds: Village: 10387312 Feature: 14357617
95017.11 23:00:08 [Server] INFO Max Entity Collisions: 8
95117.11 23:00:08 [Server] INFO Sending up to 10 chunks per packet
95217.11 23:00:08 [Server] INFO Structure Info Saving: true
95317.11 23:00:08 [Server] INFO Random Lighting Updates: false
95417.11 23:00:08 [Server] INFO Hopper Transfer: 8 Hopper Check: 8 Hopper Amount: 1
95517.11 23:00:08 [Server] INFO Entity Tracking Range: Pl 48 / An 48 / Mo 48 / Mi 32 / Other 64
95617.11 23:00:08 [Server] INFO Entity Activation Range: An 32 / Mo 32 / Mi 16
95717.11 23:00:08 [Server] INFO NetherWart Growth Modifier: 100%
95817.11 23:00:08 [Server] INFO Wheat Growth Modifier: 100%
95917.11 23:00:08 [Server] INFO Sapling Growth Modifier: 100%
96017.11 23:00:08 [Server] INFO Pumpkin Growth Modifier: 100%
96117.11 23:00:08 [Server] INFO Mushroom Growth Modifier: 100%
96217.11 23:00:08 [Server] INFO Melon Growth Modifier: 100%
96317.11 23:00:08 [Server] INFO Cane Growth Modifier: 100%
96417.11 23:00:08 [Server] INFO Cactus Growth Modifier: 100%
96517.11 23:00:08 [Server] INFO Nerfing mobs spawned from spawners: false
96617.11 23:00:08 [Server] INFO Mob Spawn Range: 4
96717.11 23:00:08 [Server] INFO Replace Blocks: [1, 5]
96817.11 23:00:08 [Server] INFO Hidden Blocks: [14, 15, 16, 21, 48, 49, 54, 56, 73, 74, 82, 129, 130]
96917.11 23:00:08 [Server] INFO Engine Mode: 1
97017.11 23:00:08 [Server] INFO Anti X-Ray: true
97117.11 23:00:08 [Server] INFO -------- World Settings For [world_the_end] --------
97217.11 23:00:08 [Server] INFO BukkitPlotGenerator does not fully support: null
97317.11 23:00:08 [Server] INFO World async lighting: false
97417.11 23:00:08 [Server] INFO Keep spawn chunk loaded: true
97517.11 23:00:08 [Server] INFO WorldServer TickNextTickList cap always processes redstone: false
97617.11 23:00:08 [Server] INFO WorldServer TickNextTick cap set at 10000
97717.11 23:00:08 [Server] INFO Allow undead horse types to be leashed: false
97817.11 23:00:08 [Server] INFO Fix TNT cannons: false
97917.11 23:00:08 [Server] INFO Water over lava flow speed: 5
98017.11 23:00:08 [Server] INFO Living Entity Despawn Ranges: Soft: 32 Hard: 128
98117.11 23:00:08 [Server] INFO Max height for cactus growth 3. Max height for reed growth 3
98217.11 23:00:08 [Server] INFO Squids will spawn between Y: 45.0 and Y: 63.0
98317.11 23:00:08 [Server] INFO Player blocking damage multiplier set to 0.5
98417.11 23:00:08 [Server] INFO Remove invalid mob spawner tile entities: true
98517.11 23:00:08 [Server] INFO -------- World Settings For [world_nether] --------
98617.11 23:00:08 [Server] INFO Experience Merge Radius: 3.0
98717.11 23:00:08 [Server] INFO Clear tick list: false
98817.11 23:00:08 [Server] INFO Chunks to Grow per Tick: 650
98917.11 23:00:08 [Server] INFO Zombie Aggressive Towards Villager: true
99017.11 23:00:08 [Server] INFO View Distance: 10
99117.11 23:00:08 [Server] INFO Allow Zombie Pigmen to spawn from portal blocks: true
99217.11 23:00:08 [Server] INFO Arrow Despawn Rate: 1200
99317.11 23:00:08 [Server] INFO Item Merge Radius: 2.5
99417.11 23:00:08 [Server] INFO Item Despawn Rate: 6000
99517.11 23:00:08 [Server] INFO Tile Max Tick Time: 50ms Entity max Tick Time: 50ms
99617.11 23:00:08 [Server] INFO Max TNT Explosions: 100
99717.11 23:00:08 [Server] INFO Custom Map Seeds: Village: 10387312 Feature: 14357617
99817.11 23:00:08 [Server] INFO Max Entity Collisions: 8
99917.11 23:00:08 [Server] INFO Sending up to 10 chunks per packet
100017.11 23:00:08 [Server] INFO Structure Info Saving: true